@@ -65,6 +65,7 @@
   #  value: (mean) value of the statistic
   #  lq: lower credible bound for the statistic
   #  uq: upper credible bound for the statistic
+  #  se: standard error for the statistic
   
   n <- length(varsel$d_test$y)
   
@@ -77,9 +78,9 @@
   se_ref <- sqrt( apply(stats_ref_pw, 2, 'var') / n ) # standard errors
   row1 <- data.frame(data = varsel$d_test$type, size=Inf, delta=F, statistic=stat_names, value=m_ref, 
                      lq=qnorm(alpha/2, mean=m_ref, sd=se_ref), uq=qnorm(1-alpha/2, mean=m_ref, sd=se_ref),
-                     row.names=1:nstats)
+                     se=se_ref, row.names=1:nstats)
   row2 <- data.frame(data = varsel$d_test$type, size=Inf, delta=T, statistic=stat_names, value=rep(0,nstats), 
-                     lq=rep(0,nstats), uq=rep(0,nstats), row.names=1:nstats)
+                     lq=rep(0,nstats), uq=rep(0,nstats), se=rep(0,nstats), row.names=1:nstats)
   rows_stat <- rbind(row1,row2)
   
   
@@ -112,7 +113,7 @@
     }
     row1 <- data.frame(data = varsel$d_test$type, size=k-1, delta=T, statistic=stat_names, value=m_diff, 
                        lq=qnorm(alpha/2, mean=m_diff, sd=se_diff), uq=qnorm(1-alpha/2, mean=m_diff, sd=se_diff),
-                       row.names=1:nstats)
+                       se=se_diff, row.names=1:nstats)
     
     # actual value
     if (all(!is.na(stats_ref_pw)) && all(n_notna < n)) {
@@ -129,14 +130,14 @@
     }
     row2 <- data.frame(data = varsel$d_test$type, size=k-1, delta=F, statistic=stat_names, value=m, 
                        lq=qnorm(alpha/2, mean=m, sd=se), uq=qnorm(1-alpha/2, mean=m, sd=se), 
-                       row.names=1:nstats)
+                       se=se, row.names=1:nstats)
     
     rows_stat <- rbind(rows_stat, row1, row2)
   }
   
   # kl-values for the submodels and the reference model (for which kl=0 and indicated by size=Inf)
   rows_kl <- data.frame(data = 'sel', size = c(seq_along(varsel$kl)-1, Inf), delta = F,
-                      statistic = 'kl',  value = c(varsel$kl, 0), lq = NA, uq = NA)
+                      statistic = 'kl',  value = c(varsel$kl, 0), lq = NA, uq = NA, se = NA)
   
   return(rbind(rows_kl, rows_stat))
 }
@@ -144,7 +145,7 @@
 
 .bootstrap_stats <- function(varsel, n_boot = 1000, alpha = 0.05) {
   #
-  # Note: this function is deprecated and not used, see tabulate stats instead.
+  # Note: this function is deprecated and not used, see tabulate_stats instead.
   #
   # return a table of summary statistics with columns:
   #
@@ -204,10 +205,13 @@
 
 
 .calc_stats <- function(mu, lppd, d_test, family, sample_weights) {
+  #
+  # Note: this function is not used.
+  #
   # calculate the average of the statistics based on pointwise mu and lppd,
   # assuming the observations are given weights sample_weights (which can be used
   # for bootstrapping the statistics)
-  arr <- list(mlpd = lppd, mse = (d_test$y-mu)^2)
+  arr <- list(mlpd = lppd, elpd = lppd*length(mu), mse = (d_test$y-mu)^2)
 
   if(family$family == 'binomial' && all(d_test$weights %in% c(0,1))) {
     arr$pctcorr <- round(mu) == d_test$y
@@ -225,25 +229,23 @@
 
 
 .pointwise_stats <- function(mu, lppd, d_test, family, sample_weights=NULL) {
+  #
   # calculate the pointwise statistics based on pointwise mu and lppd
+  #
   stats <- list()
   stats$mlpd <- lppd
+  stats$elpd <- lppd*length(mu)
   stats$mse <- (d_test$y-mu)^2
+  stats$rmse <- sqrt(stats$mse)
   
   if(family$family == 'gaussian') {
     stats$r2 <- 1 - stats$mse/mean((d_test$y-mean(d_test$y))^2)
   }
   if(family$family == 'binomial' && all(d_test$weights %in% c(0,1))) {
     stats$pctcorr <- round(mu) == d_test$y
+    stats$acc <- stats$pctcorr
   }
   
-  # avg_ <- function(x) c(sample_weights%*%x)
-  # stats <- lapply(arr, avg_)
-  
-  # if(family$family == 'gaussian') {
-  #   stats$r2 <- 1 - stats$mse/avg_((d_test$y-mean(d_test$y))^2)
-  # }
   as.data.frame(stats)
-  # stats
 }
 
